#!/bin/bash

# Check if the script is run with root privileges
if [ "$EUID" -ne 0 ]
  then echo "Please run as root"
  exit
fi

# Check if the correct number of arguments are provided
if [ "$#" -ne 2 ]; then
    echo "Usage: $0 <username> <true|false>"
    exit
fi

# Get the arguments
username=$1
new_value=$2

# Check if the user exists
if id "$username" &>/dev/null; then
    # User exists, change the SystemAccount value
    file_path="/var/lib/AccountsService/users/$username"
    if [ ! -f "$file_path" ]; then
        # File doesn't exist, create it with [User] section
        echo -e "[User]\nSystemAccount=$new_value" > "$file_path"
    elif grep -q "^SystemAccount=" "$file_path"; then
        # SystemAccount line exists, change its value
        sed -i "s/^SystemAccount=.*/SystemAccount=$new_value/" "$file_path"
    else
        # SystemAccount line doesn't exist, add it under [User]
        sed -i "/^\[User\]/a SystemAccount=$new_value" "$file_path"
    fi
    echo "SystemAccount value changed successfully for user $username."
else
    echo "User $username does not exist."
fi
